@@ -25,7 +25,9 @@ import shutil
 import tempfile
 from abc import ABC, abstractmethod
 from constant_sorrow.constants import REGISTRY_COMMITTED
-from typing import Dict, Iterator, List, Tuple, Type, Union
+from eth_typing.evm import ChecksumAddress
+from typing import Dict, Iterator, List, Tuple, Type, Union, Optional
+from web3.types import ABI
 
 from nucypher.blockchain.eth import CONTRACT_REGISTRY_BASE
 from nucypher.blockchain.eth.constants import PREALLOCATION_ESCROW_CONTRACT_NAME
@@ -492,155 +494,3 @@ class InMemoryContractRegistry(BaseContractRegistry):
 
     def _destroy(self) -> None:
         self.__registry_data = dict()
-
-
-class AllocationRegistry(LocalContractRegistry):
-
-    _multi_contract = False
-    _contract_name = PREALLOCATION_ESCROW_CONTRACT_NAME
-
-    REGISTRY_TYPE = 'allocation'
-    REGISTRY_NAME = 'allocation_registry.json'
-
-    _default_registry_filepath = os.path.join(DEFAULT_CONFIG_ROOT, REGISTRY_NAME)
-
-    class NoAllocationRegistry(BaseContractRegistry.NoRegistry):
-        pass
-
-    class AllocationEnrollmentError(RuntimeError):
-        pass
-
-    class UnknownBeneficiary(ValueError):
-        pass
-
-    def __init__(self, filepath: str = None, *args, **kwargs):
-        super().__init__(filepath=filepath or self._default_registry_filepath, *args, **kwargs)
-
-    def search(self, beneficiary_address: str = None, contract_address: str = None):
-        if not (bool(beneficiary_address) ^ bool(contract_address)):
-            raise ValueError(f"Pass either beneficiary_address or contract_address, not both. "
-                             f"Got {beneficiary_address} and {contract_address}.")
-
-        try:
-            allocation_data = self.read()
-        except BaseContractRegistry.NoRegistry:
-            raise self.NoAllocationRegistry
-
-        if beneficiary_address:
-            try:
-                contract_data = allocation_data[beneficiary_address]
-                result = contract_data
-            except KeyError:
-                raise self.UnknownBeneficiary
-
-        elif contract_address:
-            records = list()
-            for beneficiary_address, contract_data in allocation_data.items():
-                if contract_address == contract_data[0]:
-                    contract_abi = contract_data[1]
-                    records.append([beneficiary_address, contract_abi])
-            if len(records) > 1:
-                raise self.RegistryError(f"Multiple {self._contract_name} deployments found ({len(records)}) "
-                                         f"for contract address {contract_address}")
-            elif not records:
-                raise self.UnknownContract(f"No {self._contract_name} deployments found "
-                                           f"for contract address {contract_address}")
-            else:
-                result = records[0]
-
-        return result
-
-    def is_beneficiary_enrolled(self, beneficiary_address: str) -> bool:
-        try:
-            _ = self.search(beneficiary_address=beneficiary_address)
-            return True
-        except (self.UnknownBeneficiary, self.NoAllocationRegistry):
-            return False
-        # TODO: #1513 Needs a test for false case (improve unit tests for allocation registry)
-
-    def enroll(self, beneficiary_address, contract_address, contract_abi) -> None:
-        contract_data = [contract_address, contract_abi]
-        try:
-            allocation_data = self.read()
-        except self.RegistryError as e:
-            self.log.info(f"Failure while reading allocation registry when "
-                          f"enrolling {beneficiary_address} ({contract_address}): {e}")
-            allocation_data = list() if self._multi_contract else dict()  # empty registry
-
-        if beneficiary_address in allocation_data:
-            raise self.AllocationEnrollmentError("There is an existing {} deployment for {}".format(self._contract_name, beneficiary_address))
-
-        allocation_data[beneficiary_address] = contract_data
-        self.write(allocation_data)
-        self.log.info("Enrolled {}:{} into allocation registry {}".format(beneficiary_address, contract_address, self.filepath))
-
-
-class InMemoryAllocationRegistry(AllocationRegistry):
-
-    def __init__(self, *args, **kwargs) -> None:
-        super().__init__(filepath="::memory-registry::", *args, **kwargs)
-        self.__registry_data = None
-
-    def clear(self):
-        self.__registry_data = None
-
-    def _swap_registry(self, filepath: str) -> bool:
-        raise NotImplementedError
-
-    def write(self, registry_data: dict) -> None:
-        self.__registry_data = json.dumps(registry_data)
-        self._id = None
-
-    def read(self) -> dict:
-        try:
-            registry_data = json.loads(self.__registry_data)
-        except TypeError:
-            if self.__registry_data is None:
-                registry_data = dict()
-            else:
-                raise
-        return registry_data
-
-
-class IndividualAllocationRegistry(InMemoryAllocationRegistry):
-
-    REGISTRY_NAME = "individual_allocation_ABI.json"
-
-    def __init__(self,
-                 beneficiary_address: str,
-                 contract_address: str,
-                 contract_abi=None,
-                 network: str = NetworksInventory.DEFAULT,  # TODO: See #1496
-                 *args, **kwargs):
-        super().__init__(*args, **kwargs)
-
-        self.beneficiary_address = beneficiary_address
-        self.contract_address = contract_address
-
-        source_manager = RegistrySourceManager()
-
-        if not contract_abi:
-            # Download individual allocation template to extract contract_abi
-            template_data, self.__source = source_manager.fetch_latest_publication(registry_class=self.__class__,
-                                                                                   network=network)
-            individual_allocation_template = json.loads(template_data)
-            if len(individual_allocation_template) != 1:
-                raise self.InvalidRegistry("Individual allocation template must contain a single entry")
-            try:
-                contract_data = individual_allocation_template["BENEFICIARY_ADDRESS"]
-            except KeyError:
-                raise self.InvalidRegistry("Bad format of individual allocation template. "
-                                           "Expected a 'BENEFICIARY_ADDRESS' key.")
-            contract_abi = contract_data[1]
-
-        # Fill template with beneficiary and contract addresses
-        individual_allocation = {beneficiary_address: [contract_address, contract_abi]}
-        self.write(registry_data=individual_allocation)
-
-    @classmethod
-    def from_allocation_file(cls, filepath: str, **kwargs) -> 'IndividualAllocationRegistry':
-        with open(filepath) as file:
-            individual_allocation_file_data = json.load(file)
-
-        registry = cls(**individual_allocation_file_data, **kwargs)
-        return registry
