@@ -332,6 +332,7 @@ def make_card(general_config, character_options, config_file, nickname):
 @BobInterface.connect_cli('retrieve')
 @click.option('--alice', type=click.STRING, help="The card id or nickname of a stored Alice card.")
 @click.option('--ipfs', help="Download an encrypted message from IPFS at the specified gateway URI")
+@click.option('--decode', help="Decode base64 plaintext messages", is_flag=True)
 def retrieve(general_config,
              character_options,
              config_file,
@@ -341,6 +342,7 @@ def retrieve(general_config,
              message_kit,
              ipfs,
              alice,
+             decode,
              force):
     """Obtain plaintext from encrypted data, if access was granted."""
 
@@ -396,9 +398,9 @@ def retrieve(general_config,
     }
 
     response = BOB.controller.retrieve(request=bob_request_data)
-
-    # TODO: Uncomment for Demo. Fix Cleartext Deserialization.
-    # for cleartext in response['cleartexts']:
-    #     print(b64decode(cleartext))
-        
+    if decode:
+        messages = list([b64decode(r).decode() for r in response['cleartexts']])
+        emitter.echo('----------Messages----------')
+        for message in messages:
+            emitter.echo(message)
     return response
