@@ -101,13 +101,23 @@ def paint_stakes(emitter: StdoutEmitter,
 
     rows, inactive_substakes = list(), list()
     for index, stake in enumerate(stakes):
+        is_inactive = False
+
         if stake.status().is_child(Stake.Status.INACTIVE):
             inactive_substakes.append(index)
+            is_inactive = True
 
         if stake.status().is_child(Stake.Status.UNLOCKED) and not paint_unlocked:
             # This stake is unlocked.
             continue
-        rows.append(list(stake.describe().values()))
+
+        stake_description = stake.describe()
+        if is_inactive:
+            # stake is inactive - update display values since they don't make much sense to display
+            stake_description['remaining'] = 'N/A'
+            stake_description['last_period'] = 'N/A'
+
+        rows.append(list(stake_description.values()))
 
     if not rows:
         emitter.echo(f"There are no locked stakes\n")
@@ -116,7 +126,11 @@ def paint_stakes(emitter: StdoutEmitter,
 
     if not paint_unlocked and inactive_substakes:
         emitter.echo(f"Note that some sub-stakes are inactive: {inactive_substakes}\n"
-                     f"Run `nucypher stake list --all` to show all sub-stakes.", color='yellow')
+                     f"Run `nucypher stake list --all` to show all sub-stakes.\n"
+                     f"Run `nucypher stake remove-inactive --all` to remove inactive sub-stakes; removal of inactive "
+                     f"sub-stakes will reduce commitment gas costs.", color='yellow')
+        # TODO - it would be nice to provide remove-inactive hint when painting_unlocked - however, this same function
+        #  is used by remove-inactive command is run, and it is redundant to be shown then
 
 
 def prettify_stake(stake, index: int = None) -> str:
@@ -171,16 +185,18 @@ def paint_staged_stake(emitter,
                        start_period,
                        unlock_period,
                        division_message: str = None):
+    economics = stakeholder.staker.economics
     start_datetime = datetime_at_period(period=start_period,
-                                        seconds_per_period=stakeholder.staker.economics.seconds_per_period,
+                                        seconds_per_period=economics.seconds_per_period,
                                         start_of_period=True)
 
     unlock_datetime = datetime_at_period(period=unlock_period,
-                                         seconds_per_period=stakeholder.staker.economics.seconds_per_period,
+                                         seconds_per_period=economics.seconds_per_period,
                                          start_of_period=True)
+    locked_days = (lock_periods * economics.hours_per_period) // 24
 
-    start_datetime_pretty = start_datetime.local_datetime().strftime("%b %d %H:%M %Z")
-    unlock_datetime_pretty = unlock_datetime.local_datetime().strftime("%b %d %H:%M %Z")
+    start_datetime_pretty = start_datetime.local_datetime().strftime("%b %d %Y %H:%M %Z")
+    unlock_datetime_pretty = unlock_datetime.local_datetime().strftime("%b %d %Y %H:%M %Z")
 
     if division_message:
         emitter.echo(f"\n{'═' * 30} ORIGINAL STAKE {'═' * 28}", bold=True)
@@ -192,7 +208,7 @@ def paint_staged_stake(emitter,
 Staking address: {staking_address}
 ~ Chain      -> ID # {blockchain.client.chain_id} | {blockchain.client.chain_name}
 ~ Value      -> {stake_value} ({int(stake_value)} NuNits)
-~ Duration   -> {lock_periods} Days ({lock_periods} Periods)
+~ Duration   -> {locked_days} Days ({lock_periods} Periods)
 ~ Enactment  -> {start_datetime_pretty} (period #{start_period})
 ~ Expiration -> {unlock_datetime_pretty} (period #{unlock_period})
     """)
